OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendarz",
    "Tasks" : "Zadania",
    "Personal" : "Osobiste",
    "{actor} created calendar {calendar}" : "{actor} utworzył kalendarz {calendar}",
    "You created calendar {calendar}" : "Utworzyłeś kalendarz {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} usunął kalendarz {calendar}",
    "You deleted calendar {calendar}" : "Usunąłeś kalendarz {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} zaktualizował kalendarz {calendar}",
    "You updated calendar {calendar}" : "Zaktualizowałeś kalendarz {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} przywrócił kalendarz {calendar}",
    "You restored calendar {calendar}" : "Przywróciłeś kalendarz {calendar}",
    "You shared calendar {calendar} as public link" : "Udostępniłeś kalendarz {calendar} przez link publiczny",
    "You removed public link for calendar {calendar}" : "Usunąłeś link publiczny do kalendarza {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} udostępnił kalendarz {calendar} dla Ciebie",
    "You shared calendar {calendar} with {user}" : "Udostępniłeś kalendarz {calendar} dla {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} udostępnił kalendarz {calendar} dla {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} zakończył udostępnianie Tobie kalendarza {calendar}",
    "You unshared calendar {calendar} from {user}" : "Zakończyłeś udostępnianie kalendarza {calendar} dla {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} zakończył udostępnianie kalendarza {calendar} dla {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} zakończył udostępnianie kalendarza {calendar} od siebie",
    "You shared calendar {calendar} with group {group}" : "Udostępniłeś kalendarz {calendar} dla grupy {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} udostępnił kalendarz {calendar} dla grupy {group}",
    "You unshared calendar {calendar} from group {group}" : "Zakończyłeś udostępnianie kalendarza {calendar} dla grupy {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} zakończył udostępnianie kalendarza {calendar} dla grupy {group} .",
    "Untitled event" : "Wydarzenie bez tytułu",
    "{actor} created event {event} in calendar {calendar}" : "{actor} utworzył wydarzenie {event} w kalendarzu {calendar}",
    "You created event {event} in calendar {calendar}" : "Utworzyłeś wydarzenie {event} w kalendarzu {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} usunął wydarzenie {event} z kalendarza {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Usunąłeś wydarzenie {event} z kalendarza {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} zaktualizował wydarzenie {event} z kalendarza {calendar}",
    "You updated event {event} in calendar {calendar}" : "Zaktualizowałeś wydarzenie {event} w kalendarzu {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} przeniósł wydarzenie {event} z kalendarza {sourceCalendar} do kalendarza {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Przeniosłeś wydarzenie {event} z kalendarza {sourceCalendar} do kalendarza {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} przywrócił wydarzenie {event} z kalendarza {calendar}",
    "You restored event {event} of calendar {calendar}" : "Przywróciłeś wydarzenie {event} z kalendarza {calendar}",
    "Busy" : "Czekaj",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} utworzył zadanie {todo} na liście {calendar}",
    "You created to-do {todo} in list {calendar}" : "Utworzyłeś zadanie {todo} na liście {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} usunął zadanie {todo} z listy {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Usunąłeś zadanie {todo} z listy {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} zaktualizował zadanie {todo} na liście {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Zaktualizowałeś zadanie {todo} na liście {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} zakończył zadanie {todo} na liście {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Zakończyłeś zadanie {todo} na liście {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} otworzył ponownie zadanie {todo} na liście {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Otworzyłeś ponownie zadanie {todo} na liście {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} przeniósł zadanie {todo} z listy {sourceCalendar} na listę {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Przeniosłeś zadanie {todo} z listy {sourceCalendar} na listę {targetCalendar}",
    "Calendar, contacts and tasks" : "Kalendarz, kontakty i zadania",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendarz</strong> został zmodyfikowany",
    "A calendar <strong>event</strong> was modified" : "<strong>Zdarzenie</strong> kalendarza zostało zmodyfikowane",
    "A calendar <strong>to-do</strong> was modified" : "Kalendarz <strong>zadań</strong> został zmieniony",
    "Contact birthdays" : "Urodziny kontaktu",
    "Death of %s" : "Śmierć %s",
    "Untitled calendar" : "Kalendarz bez tytułu",
    "Calendar:" : "Kalendarz:",
    "Date:" : "Data:",
    "Where:" : "Gdzie:",
    "Description:" : "Opis:",
    "_%n year_::_%n years_" : ["%n rok","%n lata","%n lat","%n lat"],
    "_%n month_::_%n months_" : ["%n miesiąc","%n miesiące","%n miesięcy","%n miesięcy"],
    "_%n day_::_%n days_" : ["%n dzień","%n dni","%n dni","%n dni"],
    "_%n hour_::_%n hours_" : ["%n godzina","%n godziny","%n godzin","%n godzin"],
    "_%n minute_::_%n minutes_" : ["%n minuta","%n minuty","%n minut","%n minut"],
    "%s (in %s)" : "%s (w %s)",
    "%s (%s ago)" : "%s (%s temu)",
    "Calendar: %s" : "Kalendarz: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Opis: %s",
    "Where: %s" : "Gdzie: %s",
    "%1$s via %2$s" : "%1$s przez %2$s",
    "Cancelled: %1$s" : "Anulowane: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" zostało anulowane",
    "Re: %1$s" : "Odp: %1$s",
    "%1$s has accepted your invitation" : "Twoje zaproszenie zostało zaakceptowane przez %1$s",
    "%1$s has tentatively accepted your invitation" : "Twoje zaproszenie zostało wstępnie zaakceptowane przez %1$s",
    "%1$s has declined your invitation" : "Twoje zaproszenie zostało odrzucone przez %1$s",
    "%1$s has responded to your invitation" : "%1$s odpowiedział/a na Twoje zaproszenie",
    "Invitation updated: %1$s" : "Zaktualizowano zaproszenie: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s zaktualizował/a wydarzenie \"%2$s\"",
    "Invitation: %1$s" : "Zaproszenie: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s chce cię zaprosić na \"%2$s\"",
    "Organizer:" : "Organizator:",
    "Attendees:" : "Uczestnicy:",
    "Title:" : "Tytuł:",
    "Time:" : "Czas:",
    "Location:" : "Lokalizacja:",
    "Link:" : "Link: ",
    "Accept" : "Akceptuj",
    "Decline" : "Odrzuć",
    "More options …" : "Więcej opcji…",
    "More options at %s" : "Więcej opcji na %s",
    "Contacts" : "Kontakty",
    "{actor} created address book {addressbook}" : "{actor} utworzył książkę adresową {addressbook}",
    "You created address book {addressbook}" : "Utworzyłeś książkę adresową {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} usunął książkę adresową {addressbook}",
    "You deleted address book {addressbook}" : "Usunąłeś książkę adresową {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} zaktualizował książkę adresową {addressbook}",
    "You updated address book {addressbook}" : "Zaktualizowałeś książkę adresową {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} udostępnił Tobie książkę adresową {addressbook}",
    "You shared address book {addressbook} with {user}" : "Udostępniłeś książkę adresową {addressbook} dla {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} udostępnił książkę adresową {addressbook} dla {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} zakończył udostępnianie Tobie książki adresowej {addressbook}",
    "You unshared address book {addressbook} from {user}" : "Zakończyłeś udostępnianie książki adresowej {addressbook} dla {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} zakończył udostępnianie książki adresowej {addressbook} dla {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} zakończyłeś udostępnianie książki adresowej {addressbook} dla siebie",
    "You shared address book {addressbook} with group {group}" : "Udostępniłeś książkę adresową {addressbook} dla grupy {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} udostępnił książkę adresową {addressbook} dla grupy {group}",
    "You unshared address book {addressbook} from group {group}" : "Zakończyłeś udostępnianie książki adresowej {addressbook} dla grupy {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} zakończył udostępnianie książki adresowej {addressbook} dla grupy {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} utworzył kontakt {card} w książce adresowej {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Utworzyłeś kontakt {card} w książce adresowej {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} usunął kontakt {card} z książki adresowej {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Usunąłeś kontakt {card} z książki adresowej {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} zaktualizował kontakt {card} w książce adresowej {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Zaktualizowałeś kontakt {card} w książce adresowej {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Zmodyfikowano <strong>kontakt</strong> lub <strong>książkę adresową</strong>",
    "Accounts" : "Konta",
    "System address book which holds all accounts" : "Systemowa książka adresowa, która przechowuje wszystkie konta",
    "File is not updatable: %1$s" : "Plik nie podlega aktualizacji: %1$s",
    "Could not write to final file, canceled by hook" : "Nie można zapisać do pliku końcowego, anulowane przez hook",
    "Could not write file contents" : "Nie można zapisać zawartości pliku",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtów","%n bajtów"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Błąd podczas kopiowania pliku do lokalizacji docelowej (skopiowany: %1$s, oczekiwany rozmiar pliku: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Oczekiwany rozmiar pliku to %1$s, lecz odczytano (z klienta Nextcloud) i zapisano (do pamięci Nextcloud) %2$s. Może to być problem z siecią po stronie wysyłającej lub problem z zapisem do pamięci po stronie serwera.",
    "Could not rename part file to final file, canceled by hook" : "Nie można zmienić nazwy pliku podzielonego na plik końcowy, anulowane przez hook",
    "Could not rename part file to final file" : "Nie można zmienić nazwy pliku podzielonego na plik końcowy",
    "Failed to check file size: %1$s" : "Nie udało się sprawdzić rozmiaru pliku: %1$s",
    "Could not open file" : "Nie można otworzyć pliku",
    "Encryption not ready: %1$s" : "Szyfrowanie nie jest gotowe: %1$s",
    "Failed to open file: %1$s" : "Nie udało się otworzyć pliku: %1$s",
    "Failed to unlink: %1$s" : "Nie udało się odłączyć: %1$s",
    "Invalid chunk name" : "Nieprawidłowa nazwa fragmentu",
    "Could not rename part file assembled from chunks" : "Nie można zmienić nazwy pliku podzielonego złożonego z kawałków",
    "Failed to write file contents: %1$s" : "Nie udało się zapisać zawartości pliku: %1$s",
    "File not found: %1$s" : "Nie znaleziono pliku: %1$s",
    "System is in maintenance mode." : "Serwer jest w trybie konserwacji.",
    "Upgrade needed" : "Wymagana aktualizacja",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "%s musisz używać protokołu HTTPS aby móc korzystać z CalDAV i CardDAV w systemach iOS/macOS.",
    "Configures a CalDAV account" : "Konfiguruje konto CalDAV",
    "Configures a CardDAV account" : "Konfiguruje konto CardDAV",
    "Events" : "Wydarzenia",
    "Untitled task" : "Zadanie bez tytułu",
    "Completed on %s" : "Ukończono %s",
    "Due on %s by %s" : "Na dzień %s w %s",
    "Due on %s" : "Na dzień %s",
    "DAV system address book" : "Książka adresowa systemu DAV",
    "No outstanding DAV system address book sync." : "Brak zaległej synchronizacji książki adresowej systemu DAV.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Synchronizacja książki adresowej systemu DAV nie została jeszcze uruchomiona, ponieważ Twoja instancja ma ponad 1000 użytkowników lub wystąpił błąd. Uruchom go ręcznie, wywołując \"occ dav:sync-system-addressbook\".",
    "WebDAV endpoint" : "Adres WebDAV",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Serwer WWW nie jest jeszcze na tyle poprawnie skonfigurowany, aby umożliwić synchronizację plików, ponieważ interfejs WebDAV może być uszkodzony.",
    "Migrated calendar (%1$s)" : "Przeniesiony kalendarz (%1$s)",
    "Calendars including events, details and attendees" : "Kalendarze zawierające wydarzenia, szczegóły i uczestników",
    "Contacts and groups" : "Kontakty i grupy",
    "WebDAV" : "WebDAV",
    "First day" : "Pierwszy dzień",
    "Last day (inclusive)" : "Ostatni dzień (inclusive)",
    "Short absence status" : "Powiadomienie o krótkiej nieobecności ",
    "Long absence Message" : "Powiadomienie o długiej nieobecności ",
    "Save" : "Zapisz",
    "Disable absence" : "Wyłącz nieobecność",
    "Failed to save your absence settings" : "Niedane zapisanie ustawień nieobecności",
    "Failed to clear your absence settings" : "Nieudane kasowanie ustawień nieobecności",
    "Time zone:" : "Strefa czasowa:",
    "to" : "od",
    "Delete slot" : "Usuń przedział czasu",
    "No working hours set" : "Nie ustawiono godzin pracy",
    "Add slot" : "Dodaj przedział czasu",
    "Monday" : "Poniedziałek",
    "Tuesday" : "Wtorek",
    "Wednesday" : "Środa",
    "Thursday" : "Czwartek",
    "Friday" : "Piątek",
    "Saturday" : "Sobota",
    "Sunday" : "Niedziela",
    "Pick a start time for {dayName}" : "Wybierz dzień rozpoczęcia {dayName}",
    "Pick a end time for {dayName}" : "Wybierz dzień zakończenia {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Automatycznie ustaw status użytkownika na \"Nie przeszkadzać\" poza dostępnością, aby wyciszyć wszystkie powiadomienia.",
    "Failed to load availability" : "Nie udało się wczytać dostępności",
    "Saved availability" : "Zapisana dostępność",
    "Failed to save availability" : "Nie udało się zapisać dostępności",
    "Availability" : "Dostępność",
    "Absence" : "Nieobecność",
    "Configure your next absence period." : "Ustaw czas swojej nieobecności ",
    "Calendar server" : "Serwer kalendarza",
    "Send invitations to attendees" : "Wyślij zaproszenia do uczestników",
    "Automatically generate a birthday calendar" : "Automatycznie generuj kalendarz urodzin",
    "Birthday calendars will be generated by a background job." : "Kalendarz urodzin będzie generowany przez uruchomione zadanie w tle.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Dlatego nie będą dostępne natychmiast po włączeniu, ale pojawią się po pewnym czasie.",
    "Send notifications for events" : "Wysyłaj powiadomienia o wydarzeniach",
    "Notifications are sent via background jobs, so these must occur often enough." : "Powiadomienia są wysyłane za pośrednictwem zadań w tle, więc muszą one występować wystarczająco często.",
    "Send reminder notifications to calendar sharees as well" : "Wysyłaj przypomnienia również do udostępnionych kalendarzy",
    "Reminders are always sent to organizers and attendees." : "Przypomnienia są zawsze wysyłane do organizatorów i uczestników.",
    "Enable notifications for events via push" : "Włącz powiadomienia o zdarzeniach poprzez Push",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Zainstaluj także {calendarappstoreopen}aplikację Kalendarz{linkclose} lub {calendardocopen}połącz swój komputer i telefon komórkowy, aby zsynchronizować ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Upewnij się, że poprawnie skonfigurowałeś {emailopen}serwer poczty{linkclose}.",
    "There was an error updating your attendance status." : "Wystąpił błąd zmiany stanu uczestnictwa",
    "Please contact the organizer directly." : "Skontaktuj się bezpośrednio z orgnizatorem.",
    "Are you accepting the invitation?" : "Czy akceptujesz zaproszenie?",
    "Tentative" : "Niepewne",
    "Your attendance was updated successfully." : "Twoja obecność została pomyślnie zaktualizowana.",
    "To-dos" : "Do zrobienia",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Jeśli skonfigurujesz godziny pracy, inni użytkownicy będą widzieć, kiedy jesteś poza biurem, gdy będą rezerwować spotkanie."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
